==> elasticsearch-java-7.15.1-sources.jar: co/elastic/clients/elasticsearch/_types/TransformBuilders.java <==
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

//----------------------------------------------------
// THIS CODE IS GENERATED. MANUAL EDITS WILL BE LOST.
//----------------------------------------------------

package co.elastic.clients.elasticsearch._types;

/**
 * Builders for {@link Transform} variants.
 */
public class TransformBuilders {
	private TransformBuilders() {
	}

	/**
	 * Creates a builder for the {@link ChainTransform chain} {@code Transform}
	 * variant.
	 */
	public static ChainTransform.Builder chain() {
		return new ChainTransform.Builder();
	}

	/**
	 * Creates a builder for the {@link ScriptTransform script} {@code Transform}
	 * variant.
	 */
	public static ScriptTransform.Builder script() {
		return new ScriptTransform.Builder();
	}

	/**
	 * Creates a builder for the {@link SearchTransform search} {@code Transform}
	 * variant.
	 */
	public static SearchTransform.Builder search() {
		return new SearchTransform.Builder();
	}

}

==> elasticsearch-java-7.17.3-sources.jar: co/elastic/clients/elasticsearch/_types/TransformBuilders.java <==
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

//----------------------------------------------------
// THIS CODE IS GENERATED. MANUAL EDITS WILL BE LOST.
//----------------------------------------------------

package co.elastic.clients.elasticsearch._types;

/**
 * Builders for {@link Transform} variants.
 * <p>
 * Variants <code>chain</code> are not available here as they don't have a
 * dedicated class. Use {@link Transform}'s builder for these.
 * 
 */
public class TransformBuilders {
	private TransformBuilders() {
	}

	/**
	 * Creates a builder for the {@link ScriptTransform script} {@code Transform}
	 * variant.
	 */
	public static ScriptTransform.Builder script() {
		return new ScriptTransform.Builder();
	}

	/**
	 * Creates a builder for the {@link SearchTransform search} {@code Transform}
	 * variant.
	 */
	public static SearchTransform.Builder search() {
		return new SearchTransform.Builder();
	}

}
